This folder contains the rrd files for the data collected by the populate.py scripts. The rrd files are stored in the rrd format and can be read by the rerun. The rrd files are updated every 5 minutes by the monitoring scripts.

You can download the file from your instance by calling the url: `https://<your_instance_ip>/cell/rerun/nova.rrd`
